<?php

namespace App\Http\Controllers\Admin\Job;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Brian2694\Toastr\Facades\Toastr;
use App\Models\Job;

class JobController extends Controller
{
    public function index()
    {
        $jobs = Job::orderBy('id', 'desc')->get();
        return view('admin.jobs.index', compact('jobs'));
    }

    public function create()
    {
        return view('admin.jobs.create');
    }

    public function store(Request $request)
    {
        $this->validate($request, [
            'title' => 'required',
            'description' => 'required',
            'location' => 'required',
            'salary' => 'nullable|numeric',
            'type' => 'required',
            'restaurant_name' => 'nullable|string',
            'experience' => 'nullable|integer',
            'address' => 'nullable|string',
            'city' => 'nullable|string',
            'state' => 'nullable|string',
            'postal_code' => 'nullable|string',
            'specialities' => 'nullable|string',
        ]);

        $input = $request->all();
        $input['user_id'] = Auth::user()->id;
        $input['date'] = now();
        $input['user_type'] = 'admin';

        Job::create($input);

        Toastr::success('Job created successfully.', 'Success');
        return redirect()->route('jobs.index');
    }

    public function edit($id)
    {
        $job = Job::find($id);
        return view('admin.jobs.edit', ['content' => $job]);

    }

    public function update(Request $request, $id)
    {
        $job = Job::find($id);

        $this->validate($request, [
            'title' => 'required',
            'description' => 'required',
            'location' => 'required',
            'salary' => 'nullable|numeric',
            'type' => 'required',
            'restaurant_name' => 'nullable|string',
            'experience' => 'nullable|integer',
            'address' => 'nullable|string',
            'city' => 'nullable|string',
            'state' => 'nullable|string',
            'postal_code' => 'nullable|string',
            'specialities' => 'nullable|string',
        ]);

        $input = $request->all();
        $job->update($input);

        Toastr::success('Job updated successfully', 'Success');
        return redirect()->route('jobs.index');
    }

    public function destroy($id)
    {
        $job = Job::find($id);
        $job->delete();

        Toastr::success('Job deleted successfully', 'Success');
        return redirect()->route('jobs.index');
    }

    public function status($id)
    {
        $job = Job::find($id);
        if (!$job) {
            return redirect()->back()->with('error', 'Job not found');
        }

        $job->status = $job->status == '0' ? '1' : '0';
        $job->save();

        return redirect()->back()->with('success', 'Job status updated successfully');
    }
}
