<?php

namespace App\Http\Controllers\Admin\Post;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Brian2694\Toastr\Facades\Toastr;
use App\Models\Post;

class PostController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $posts = Post::with(['user', 'reactions', 'comments.replies'])
                ->orderBy('id', 'desc')
                ->get();
        return view('admin.posts.index', compact('posts'));
    }
     /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Content  $category
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $review = Post::find($id);
        $review->delete();

        Toastr::success('Review deleted successfully', 'Success');
        return redirect()->route('reviews.index');
    }

    public function status($id)
    {
        $post = Post::find($id);
        if (!$post) {
            return redirect()->back()->with('error', 'Post not found');
        }

        $post->status = $post->status == '0' ? '1' : '0';
        $post->save();

        return redirect()->back()->with('success', 'Post status update successfully');
    }
    
    public function show($id)
    {
        try {
            $post = Post::with([
                'user:id,name,image',
                'images:id,post_id,image',
                'reactions',
                'comments' => function ($q) {
                    $q->with([
                        'user:id,name,image',
                        'replies' => function ($q) {
                            $q->with('user:id,name,image');
                        }
                    ]);
                }
            ])->find($id);

            if (!$post) {
                abort(404);
            }

            $likesCount = $post->reactions->where('type', 'like')->count();
            $dislikesCount = $post->reactions->where('type', 'dislike')->count();

            return view('admin.posts.detail', [
                'post' => $post,
                'likesCount' => $likesCount,
                'dislikesCount' => $dislikesCount,
                'commentsCount' => $post->comments->count()
            ]);

        } catch (\Exception $e) {
            abort(500, 'Failed to load post details');
        }
    }
}
