<?php

namespace App\Http\Controllers\Admin\Review;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Brian2694\Toastr\Facades\Toastr;
use App\Models\Review;

class ReviewController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $reviews = Review::with('images')->orderBy('id', 'desc')->get();
        return view('admin.reviews.index', compact('reviews'));
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.reviews.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name' => 'required',
            'value' => 'required',
        ]);

        $input = $request->all();
        $input['added_by'] = Auth::user()->id;

        Review::create($input);

        Toastr::success('Review created successfully.', 'Success');
        return redirect()->route('reviews.index');
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Content  $content
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $review = Review::find($id);

        return view('admin.reviews.edit', compact('review'));
    }

    
    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Content  $content
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $review = Review::find($id);

        $this->validate($request, [
            'name' => 'required',
            'value' => 'required',
        ]);

        $input = $request->all();

        $review->update($input);

        Toastr::success('Review updated successfully', 'Success');
        return redirect()->route('reviews.index');
    }

     /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Content  $category
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $review = Review::find($id);
        $review->delete();

        Toastr::success('Review deleted successfully', 'Success');
        return redirect()->route('reviews.index');
    }

    public function status($id)
    {
        $review = Review::find($id);
        if (!$review) {
            return redirect()->back()->with('error', 'Review not found');
        }

        $review->status = $review->status == '0' ? '1' : '0';
        $review->save();

        return redirect()->back()->with('success', 'Review status updated successfully');
    }
}
