<?php

namespace App\Http\Controllers\Api\Home;

use App\Models\Review;
use App\Models\ChiefPost;
use App\Models\Post;
use App\Models\Job;
use Illuminate\Support\Facades\Validator;
use App\Models\JobApply;
use Auth;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Http\Traits\ApiResponse;
use Spatie\Permission\Traits\HasRoles;
use Illuminate\Support\Str;
use Carbon\Carbon;

class HomeController extends Controller
{
    use ApiResponse, HasRoles;

    public function review(Request $request) 
    {
        $reviews = Review::where('status', '0')
        ->where('rating', '5')
        ->with(['user:id,name,image', 'images:id,review_id,image'])
        ->select('id', 'user_id', 'rating', 'date', 'status', 'description')
        ->latest()
        ->take(6)
        ->get()
        ->map(function ($review) {
            $review->description = Str::limit($review->description, 100);
            $review->reaction_counts = $review->getReactionCounts();
                
                $review->images = $review->images->isEmpty()
                ? [['image' => asset('public/uploads/default/default.png')]]
                : $review->images->map(function ($image) {
                    return [
                        'image' => asset('public/' . ltrim(str_replace('public/', '', $image->image), '/'))
                    ];
                })->toArray();
            
            return $review;
            });
            
        return response()->json([
            'status' => 'success',
            'message' => 'Reviews fetched successfully',
            'data' => $reviews,
        ], 200);
    }
    
    public function userLatestReview(Request $request) 
    {
        $userLatestReview = Review::where('status', '0')
            ->where('rating', '5')
            ->with(['user:id,name,image'])
            ->select('id', 'user_id', 'date')
            ->latest()
            ->take(5)
            ->get()
            ->map(function ($review) {
                return [
                    'name' => $review->user->name,
                    'image' => $review->user->image 
                    ? asset(str_replace('public/', '', $review->user->image)) 
                    : asset('uploads/default/default.png'),
                    'date' => $review->date->diffForHumans() // ago format
                ];
            });
            
        return response()->json([
            'status' => 'Success',
            'message' => 'Reviews Listing successfully',
            'data' => $userLatestReview,
        ], 200);
    }
    
    public function userLatestCommunity(Request $request)
    {
        $latestUsers = Post::where('status', '0')
            ->with(['user:id,name,image'])
            ->select('id', 'user_id', 'date')
            ->latest()
            ->take(5)
            ->get()
            ->map(function ($post) {
                return [
                    'name' => $post->user->name,
                    'image' => $post->user->image 
                    ? asset(str_replace('public/', '', $post->user->image)) 
                    : asset('uploads/default/default.png'),
                    'date_ago' => Carbon::parse($post->date)->diffForHumans()
                ];
            })
            ->unique('name')
            ->values();
                
        return response()->json([
            'status' => 1,
            'message' => 'Post Listing successfully',
            'data' => $latestUsers,
        ], 200);
    }
    
    public function chefLatestPost(Request $request)
    {
        $latestUsers = ChiefPost::where('status', '0')
            ->with(['user:id,name,image'])
            ->select('id', 'user_id', 'date')
            ->latest()
            ->take(5)
            ->get()
            ->map(function ($post) {
                return [
                    'name' => $post->user->name,
                    'image' => $post->user->image 
                    ? asset(str_replace('public/', '', $post->user->image)) 
                    : asset('uploads/default/default.png'),
                    'date_ago' => Carbon::parse($post->date)->diffForHumans()
                ];
            })
            ->unique('name')
            ->values();
                
        return response()->json([
            'status' => 1,
            'message' => 'Post Listing successfully',
            'data' => $latestUsers,
        ], 200);
    }
    
    public function jobListings(Request $request)
    {
        $jobs = Job::where('status', '0')
            ->latest()
            ->take(4)
            ->get();
    
        return response()->json([
            'status' => 'success',
            'message' => 'Job listings successfully',
            'data' => $jobs,
        ], 200);
    }
    
    public function jobDetail(Request $request, $id)
    {
        $job = Job::where('status', '0')
            ->where('id', $id)
            ->with('user:id,name,image')
            ->first();
    
        if (!$job) {
            return response()->json([
                'status' => 'error',
                'message' => 'Job not found',
                'data' => null,
            ], 404);
        }
    
        return response()->json([
            'status' => 'success',
            'message' => 'Job Details successfully',
            'data' => $job,
        ], 200);
    }
    
    // public function applyJob(Request $request)
    // {
    //     $validator = Validator::make($request->all(), [
    //         'job_id' => 'required|exists:jobs,id',
    //         // 'resume' => 'required|file|mimes:pdf,doc,docx|max:2048',
    //         'resume' => 'required',
    //         'cover_letter' => 'nullable|string|max:5000'
    //     ]);

    //     if ($validator->fails()) {
    //         return response()->json([
    //             'status' => 'Error',
    //             'message' => 'Validation error',
    //             'data' => $validator->errors()
    //         ], 422);
    //     }

    //     // Check if the job exists and is active
    //     $job = Job::where('id', $request->job_id)
    //         ->where('status', '0')
    //         ->first();

    //     if (!$job) {
    //         return response()->json([
    //             'status' => 'error',
    //             'message' => 'Job not found or inactive',
    //             'data' => null,
    //         ], 404);
    //     }

    //     if (!auth()->check()) {
    //         return response()->json([
    //             'status' => 'Error',
    //             'message' => 'Unauthorized'
    //         ], 401);
    //     }
    
        
    //     $existingApplication = JobApply::where('user_id', Auth::id())
    //         ->where('job_id', $request->job_id)
    //         ->first();

    //     if ($existingApplication) {
    //         return response()->json([
    //             'status' => 'Error',
    //             'message' => 'You have already applied for this job',
    //             'data' => null,
    //         ], 409);
    //     }
        
        
    //     $resumePath = null;
    //     if ($request->hasFile('resume')) {
    //         $file = $request->file('resume');
    //         $fileName = time() . '_' . Str::random(10) . '.' . $file->getClientOriginalExtension();
    //         $destinationPath = public_path('uploads/jobs/resume');

    //         if (!file_exists($destinationPath)) {
    //             mkdir($destinationPath, 0755, true);
    //         }

    //         $file->move($destinationPath, $fileName);
    //         $resumePath = 'public/uploads/jobs/resume/' . $fileName;
    //     }

    //     // Create job application
    //     $jobApply = JobApply::create([
    //         'user_id' => Auth::id(),
    //         'job_id' => $request->job_id,
    //         'resume' => $resumePath,
    //         'cover_letter' => $request->cover_letter,
    //     ]);

    //     return response()->json([
    //         'status' => 'Success',
    //         'message' => 'Job application submitted successfully',
    //         'data' => $jobApply,
    //     ], 201);
    // }
    
    public function applyJob(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'job_id' => 'required|exists:jobs,id',
            'resume' => 'required',
            'cover_letter' => 'required'
        ]);

        if ($validator->fails()) {
            return response()->json([
                'status' => 'Error',
                'message' => 'Validation error',
                'data' => $validator->errors()
            ], 422);
        }

        // Check if the job exists and is active
        $job = Job::where('id', $request->job_id)
            ->where('status', '0')
            ->first();

        if (!$job) {
            return response()->json([
                'status' => 'Error',
                'message' => 'Job not found or inactive',
                'data' => null,
            ], 404);
        }

        if (!auth()->check()) {
            return response()->json([
                'status' => 'Error',
                'message' => 'Unauthorized'
            ], 401);
        }

        // Check if the user has already applied for this job
        $existingApplication = JobApply::where('user_id', Auth::id())
            ->where('job_id', $request->job_id)
            ->first();

        if ($existingApplication) {
            return response()->json([
                'status' => 'Error',
                'message' => 'You have already applied for this job',
                'data' => null,
            ], 409);
        }

        $resumePath = null;
        if ($request->hasFile('resume')) {
            $file = $request->file('resume');
            $fileName = time() . '_' . Str::random(10) . '.' . $file->getClientOriginalExtension();
            $destinationPath = public_path('uploads/jobs/resume');

            if (!file_exists($destinationPath)) {
                mkdir($destinationPath, 0755, true);
            }

            $file->move($destinationPath, $fileName);
            $resumePath = 'uploads/jobs/resume/' . $fileName; // Adjusted path to remove 'public/'
        }

        // Create job application
        $jobApply = JobApply::create([
            'user_id' => Auth::id(),
            'job_id' => $request->job_id,
            'resume' => $resumePath,
            'cover_letter' => $request->cover_letter,
        ]);

        return response()->json([
            'status' => 'Success',
            'message' => 'Job application submitted successfully',
            'data' => $jobApply,
        ], 201);
    }
    
}
