<?php

namespace App\Http\Controllers\API\Message;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Message;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;

class MessageController extends Controller
{
    /**
     * Display a listing of messages.
     */
    public function index()
    {
        $messages = Message::latest()->get();

        return response()->json([
            'status' => 'Success',
            'message' => 'Messages Listing successfully',
            'data' => $messages,
        ]);
    }

    /**
     * Store a newly created message using authenticated user ID.
     */
    public function store(Request $request)
    {
        $request->validate([
            'content' => 'required|string|max:1000',
        ]);

        $userId = Auth::id();

        if (!$userId) {
            return response()->json([
                'status' => false,
                'message' => 'Unauthorized',
            ], 401);
        }

        $message = Message::create([
            'user_id' => $userId,
            'content' => $request->content,
        ]);

        return response()->json([
            'status' => 'Success',
            'message' => 'Message Sent successfully.',
            'data' => $message,
        ], 201);
    }
}
