<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Providers\RouteServiceProvider;
use Illuminate\Foundation\Auth\AuthenticatesUsers;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use App\Models\User;
use App\Models\Setting;

class LoginController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Login Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles authenticating users for the application and
    | redirecting them to your home screen. The controller uses a trait
    | to conveniently provide its functionality to your applications.
    |
    */

    use AuthenticatesUsers;

    /**
     * Where to redirect users after login.
     *
     * @var string
     */
    protected $redirectTo = RouteServiceProvider::HOME;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest')->except('logout');
    }

    public function showLoginForm()
    {
        $data = [
            'favicon' => Setting::where('name', 'favicon')->first()->value ?? 'default-favicon.ico',
            'logo' => Setting::where('name', 'logo')->first()->value ?? 'default-logo.png',
        ];
        return view('auth.login', compact('data'));
    }

    public function login(Request $request)
    {
        $credentials = $request->validate([
            'email' => ['required', 'email'],
            'password' => ['required'],
        ]);


        $user = User::where('email', $request->email)->first();


        if (!$user) {
            return back()->withErrors([
                'email' => 'These credentials do not match our records.',
            ]);
        }


        if ($user->hasRole(['user'])) {
            return back()->withErrors([
                'email' => 'These credentials do not match our records.',
            ]);
        }

        if (Auth::attempt($credentials)) {

            $request->session()->regenerate();

            return redirect()->route('dashboards.index');
        }


        return back()->withErrors([
            'email' => 'These credentials do not match our records.',
        ]);
    }
}
