<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Spatie\Activitylog\LogOptions;
use Spatie\Activitylog\Traits\LogsActivity;

class Review extends Model
{
    use HasFactory, LogsActivity;

    protected $fillable = ['user_id', 'rating', 'description', 'status', 'date'];
    protected $dates = ['date'];

    public static $reactionTypes = [
        'thanks' => 'Thanks',
        'helpful' => 'Helpful',
        'love_this' => 'Love this',
        'oh_no' => 'Oh no',
    ];
    
    public function user()
    {
        return $this->belongsTo(User::class, 'user_id');
    }
    
    public function getImageAttribute($value)
    {
        if (!$value) {
            return asset('/uploads/default/default.png');
        }
        return asset(str_replace('public/', '', $value));
    }

    public function images()
    {
        return $this->hasMany(ReviewImage::class);
    }

    public function reactions()
    {
        return $this->hasMany(ReviewReaction::class);
    }

    public function getActivitylogOptions(): LogOptions
    {
        return LogOptions::defaults()
            ->logOnly(['user_id', 'rating', 'description', 'status', 'date'])
            ->logOnlyDirty()
            ->dontSubmitEmptyLogs();
    }

    public function getReactionCounts()
    {
        return [
            'thanks' => $this->reactions()->where('type', 'thanks')->count(),
            'helpful' => $this->reactions()->where('type', 'helpful')->count(),
            'love_this' => $this->reactions()->where('type', 'love_this')->count(),
            'oh_no' => $this->reactions()->where('type', 'oh_no')->count(),
        ];
    }
}
