<?php

namespace App\Models;

use App\Classes\Helper;
use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Spatie\Activitylog\Traits\LogsActivity;
use Illuminate\Support\Facades\Auth;
// use Laravel\Sanctum\HasApiTokens;
use Laravel\Passport\HasApiTokens;
use Spatie\Permission\Traits\HasRoles;
use Spatie\Activitylog\LogOptions;

class User extends Authenticatable
{
    use HasApiTokens, HasFactory, Notifiable, HasRoles, LogsActivity;

    protected $guard = 'api';

    public const STATUS_ACTIVE = 0;
    public const STATUS_INACTIVE = 1;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */

    public function getActivitylogOptions(): LogOptions
    {
        return LogOptions::defaults()
        ->logOnly(['name', 'text']);
    }

    protected $fillable = [
        'name', 'email', 'user_type_id', 'type', 'experience', 'speciality', 'phone', 'gender', 'image', 'address', 'password', 'otp', 'about', 'device_type', 'device_token', 'verified_by', 'social_provider', 'social_token', 'social_id', 'status' , 'is_deactivate', 'email_verified_at'
    ];

    protected static $logAttributes = ['name', 'email', 'user_type_id', 'type', 'experience', 'speciality', 'phone', 'image', 'address','password', 'otp', 'about', 'device_type', 'device_token', 'verified_by', 'social_provider', 'social_token', 'social_id', 'status' , 'is_deactivate', 'email_verified_at'];
    protected static $logName = 'User';
    protected static $logOnlyDirty = true;

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];
    
    
    public function reviews()
    {
        return $this->hasMany(Review::class);
    }

    public function community()
    {
        return $this->hasMany(Post::class);
    }
    
    public function getImageAttribute($value)
    {
        if (!$value) {
            return asset('/uploads/default/default.png');
        }
        return asset(str_replace('public/', '', $value));
    }
    
    public function chiefPosts()
    {
        return $this->hasMany(ChiefPost::class);
    }
    
    public function chiefPostImages()
    {
        return $this->hasMany(ChiefPostImage::class);
    }

    /**
     * Get all ChiefPostReactions made by the user.
     */
    public function chiefPostReactions()
    {
        return $this->hasMany(ChiefPostReaction::class);
    }

    /**
     * Get all ChiefComments made by the user.
     */
    public function chiefComments()
    {
        return $this->hasMany(ChiefComment::class);
    }

    /**
     * Get all ChiefCommentReplies made by the user.
     */
    public function chiefCommentReplies()
    {
        return $this->hasMany(ChiefCommentReply::class);
    }
}
