<?php

use App\Http\Controllers\Api\Post\PostController;
use App\Http\Controllers\Api\Auth\AuthController;
use App\Http\Controllers\Api\Review\ReviewController;
use App\Http\Controllers\Api\Home\HomeController;
use App\Http\Controllers\Api\ChiefPost\ChiefPostController;
use App\Http\Controllers\Api\Message\MessageController;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

Route::group(["prefix" => "v1"], function () {

    // Users
    // Route::group(["prefix" => "user"], function () {

        Route::controller(AuthController::class)->group(function () {
            Route::post("register", "register");
            Route::post("login", "login");
            Route::post("verify-otp", "verifyOtp");
            Route::post("resend-otp", "resendOtp");
            Route::post("forgot-password", "forgotPassword");
            Route::post("reset-password", "resetPassword");

            Route::group(['prefix' => 'social'], function() {
                Route::post('/google', "googleAuth");
                Route::post('/facebook', "facebookAuth");
                Route::post('/apple', "appleAuth");
            });

            Route::middleware(["auth:api"])->group(function () {
                Route::get("getProfile", "getProfile");
                Route::post("update-profile", "updateProfile");
                Route::post("update-password", "updatePassword");
                Route::delete("delete-account", "deleteAccount");
                Route::post("saveUserDeviceToken", "saveUserDeviceToken");
                Route::post("logout", "logout");
            });
        });

        // Notifications
        // Route::controller(NotificationController::class)->prefix("notifications")->middleware(["auth:api"])->group(function () {
            
        //     Route::get("/", "index");
        //     Route::post("/notificationRead", "notificationRead");
        //     Route::delete("/notificationDelete", "notificationDelete");
        // });


        // Reviews
        Route::controller(ReviewController::class)->prefix('reviews')->group(function () {
            Route::get('/listing', 'listing');
                
            Route::middleware('auth:api')->group(function () {
                Route::post('/create', 'create');
                Route::post('/reactions', 'reaction');
                Route::delete("/delete", "delete");
            });
        });

        // Post
        Route::controller(PostController::class)->prefix("posts")->group(function () {
            Route::get("/listing", "listing");
            
            Route::middleware('auth:api')->group(function () {
                Route::post("/create", "create");
                Route::post("/reactions", "reaction");
                Route::delete("/delete", "delete");
                Route::post("/comments", "commentStore");
                Route::delete("/comments/delete", "commentDelete");
                Route::post("/replies", "replyStore");
                Route::delete("/replies/delete", "replyDelete");
            });
        });
        
        Route::controller(ChiefPostController::class)->prefix("chief-posts")->group(function () {
            Route::get("/listing", "listing");
            
            Route::middleware('auth:api')->group(function () {
                Route::post("/create", "create");
                Route::post("/reactions", "reaction");
                Route::post("/comments", "commentStore");
                Route::delete("/delete", "delete");
                Route::delete("/comments/delete", "commentDelete");
                Route::post("/replies", "replyStore");
                Route::delete("/replies/delete", "replyDelete");
            });
        });
        
        // Dashboard
        Route::controller(HomeController::class)->prefix('home')->group(function () {
            Route::get('/reviews', 'review');
            Route::get('/user-latest-reviews', 'userLatestReview');
            Route::get('/user-latest-communities', 'userLatestCommunity');
            Route::get('/chef-latest-posts', 'chefLatestPost');
            Route::get('/job-listings', 'jobListings');
            Route::get('/job/detail/{id}', 'jobDetail');
            Route::middleware('auth:api')->group(function () {
                Route::post('/job-applies', 'applyJob');
            });
        });
        
        Route::controller(MessageController::class)->prefix("messages")->middleware('auth:api')->group(function () {
            Route::get("/listing", "index");
            Route::post("/create", "store");
        });
        // Route::get('/home', [HomeController::class, 'index']);

        
    // });

});

Route::fallback(
    function (Request $request) {
        if ($request->is("api/*")) {
            return response()->json(["message" => "Not Found."], 404);
        }
    }
);