<?php

use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Auth;

use App\Http\Controllers\Auth\LoginController;
use App\Http\Controllers\Admin\Permission\PermissionController;
use App\Http\Controllers\Admin\Role\RoleController;
use App\Http\Controllers\Admin\User\UserController;
use App\Http\Controllers\Admin\Content\ContentController;
use App\Http\Controllers\Admin\Dashboard\DashboardController;
use App\Http\Controllers\Admin\Review\ReviewController;
use App\Http\Controllers\Admin\Post\PostController;
use App\Http\Controllers\Admin\Job\JobController;

use App\Http\Controllers\Admin\Setting\SettingController;
use App\Http\Controllers\Admin\Log\LogController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/
Route::middleware('prevent-back-history')->group(function () {
    
    Route::get('/', function () {
        return redirect('/login');
    })->name('home');

    Auth::routes([
      'register' => false, // Registration Routes...
      'reset' => false, // Password Reset Routes...
      'verify' => false, // Email Verification Routes...
    ]);

    Route::get('/home', function () {
        return redirect('/admin/users');
    });


    Route::group(['prefix' => 'admin'], function () {
        Route::get('/', function () {
            return redirect()->route('login');
        });

        Route::get('/login', [LoginController::class, 'showLoginForm'])->name('login');
        Route::post('/login', [LoginController::class, 'login']);
        Route::post('/logout', [LoginController::class, 'logout'])->name('logout')->middleware('auth');

        Route::group(['middleware' => 'auth'], function () {

            // Dashboard
            Route::get('/dashboard', [DashboardController::class, 'index'])->name('dashboards.index')->middleware('permission:dashboard-list');
            
            Route::controller(UserController::class)->prefix('users')->group(function () {

                Route::get('/', 'index')->name('users.index')->middleware('permission:user-list');
                Route::get('/create', 'create')->name('users.create')->middleware('permission:user-create');
                Route::post('', 'store')->name('users.store')->middleware('permission:user-create');
                Route::patch('/{user}', 'update')->name('users.update')->middleware('permission:user-edit');
                Route::get('/{user}/edit', 'edit')->name('users.edit')->middleware('permission:user-edit');
                Route::get('/{user}/userProfile', 'userProfile')->name('users.userProfile')->middleware('permission:user-edit');
                Route::patch('{user}/update', 'userUpdateProfile')->name('users.updateProfile')->middleware('permission:user-edit');
                Route::delete('/{user}', 'destroy')->name('users.destroy')->middleware('permission:user-delete');
                Route::get('password/change', 'changePassword')->name('users.changePassword')->middleware('permission:user-edit');
                Route::post('password/change', 'updatePassword')->name('users.updatePassword')->middleware('permission:user-edit');
                
                Route::post('get-locations', 'getLocations')->name('users.getLocations');
                Route::post('get-sites', 'getSites')->name('users.getSites');
            });

            // Roles
            Route::controller(RoleController::class)->prefix('roles')->group(function () {

                Route::get('/', 'index')->name('roles.index')->middleware('permission:role-list');
                Route::get('/create', 'create')->name('roles.create')->middleware('permission:role-create');
                Route::post('', 'store')->name('roles.store')->middleware('permission:role-create');
                Route::patch('/{role}', 'update')->name('roles.update')->middleware('permission:role-edit');
                Route::get('/{role}/edit', 'edit')->name('roles.edit')->middleware('permission:role-edit');
                Route::delete('/{role}', 'destroy')->name('roles.destroy')->middleware('permission:role-delete');
            });

            // Permissions
            Route::controller(PermissionController::class)->prefix('permissions')->group(function () {

                Route::get('/', 'index')->name('permissions.index')->middleware('permission:permission-list');
                Route::get('/create', 'create')->name('permissions.create')->middleware('permission:permission-create');
                Route::post('', 'store')->name('permissions.store')->middleware('permission:permission-create');
                Route::patch('/{permission}', 'update')->name('permissions.update')->middleware('permission:permission-edit');
                Route::get('/{permission}/edit', 'edit')->name('permissions.edit')->middleware('permission:permission-edit');
                Route::delete('/{permission}', 'destroy')->name('permissions.destroy')->middleware('permission:permission-delete');
            });

            // Reviews
            Route::controller(ReviewController::class)->prefix('reviews')->group(function () {

                Route::get('/', 'index')->name('reviews.index')->middleware('permission:review-list');
                Route::get('/create', 'create')->name('reviews.create')->middleware('permission:review-create');
                Route::post('', 'store')->name('reviews.store')->middleware('permission:review-create');
                Route::patch('/{review}', 'update')->name('reviews.update')->middleware('permission:review-edit');
                Route::get('/{review}/edit', 'edit')->name('reviews.edit')->middleware('permission:review-edit');
                Route::get('/{review}/status', 'status')->name('reviews.status')->middleware('permission:review-edit');
                Route::delete('/{review}', 'destroy')->name('reviews.destroy')->middleware('permission:review-delete');
            });
            
            Route::controller(JobController::class)->prefix('jobs')->group(function () {

                Route::get('/', 'index')->name('jobs.index')->middleware('permission:job-list');
                Route::get('/create', 'create')->name('jobs.create')->middleware('permission:job-create');
                Route::post('', 'store')->name('jobs.store')->middleware('permission:job-create');
                Route::patch('/{job}', 'update')->name('jobs.update')->middleware('permission:job-edit');
                Route::get('/{job}/edit', 'edit')->name('jobs.edit')->middleware('permission:job-edit');
                Route::get('/{job}/status', 'status')->name('jobs.status')->middleware('permission:job-edit');
                Route::delete('/{job}', 'destroy')->name('jobs.destroy')->middleware('permission:job-delete');
            });
            
            //
            Route::controller(PostController::class)->prefix('communities')->group(function () {

                Route::get('/', 'index')->name('posts.index')->middleware('permission:community-list');
                Route::get('/{post}/status', 'status')->name('posts.status')->middleware('permission:community-edit');
                Route::get('/posts/{post}', 'show')->name('posts.show');
            });
            
            // Logs
            Route::controller(LogController::class)->prefix('logs')->group(function () {

                Route::get('/', 'index')->name('logs.index')->middleware('permission:log-list');
                Route::post('/search', 'IndexController@logsSearch')->name('logs.search')->middleware('permission:log-list');
            });

            // Settings
            Route::controller(SettingController::class)->prefix('settings')->middleware('permission:setting-list')->group(function () {

                Route::get('', 'index')->name('settings.index')->middleware('permission:setting-list');
                Route::post('', 'store')->name('settings.store')->middleware('permission:setting-list');    
                Route::get('/updates', 'index')->name('update.index')->middleware('permission:updates-list');
                Route::get('/updates/add', 'create')->name('update.create')->middleware('permission:updates-create');
                Route::post('/updates/store', 'store')->name('update.store')->middleware('permission:updates-create');
                Route::get('/updates/edit/{id}', 'edit')->name('update.edit')->middleware('permission:updates-edit');      
                Route::post('/updates/update/{id}', 'update')->name('updates.edit')->middleware('permission:updates-edit');        
                Route::post('/updates/delete/{id}', 'destroy')->name('update.delete')->middleware('permission:updates-delete');

                // Route::get('/information', 'contactInformation')->name('settings.information');
                // Route::get('/social', 'social')->name('settings.social');
                // Route::get('/fav-logo', 'favLogo')->name('settings.favLogo');
                // Route::patch('/update-contact', 'updateContact')->name('settings.contactUpdate');
                // Route::patch('/update-social', 'updateSocial')->name('settings.socialUpdate');
                // Route::patch('/logo-favicon', 'logoFavicon')->name('settings.logoFavIconUpdate');
            });
        });
    });
});